@@ -146,15 +146,15 @@ void KUrlCompletionTest::testLocalRelativePath()
     QStringList comp1all = m_completion->allMatches();
     qDebug() << comp1all;
     QCOMPARE(comp1all.count(), 4);
-    QVERIFY(comp1all.contains(QStringLiteral("file1")));
-    QVERIFY(comp1all.contains(QStringLiteral("file#a")));
-    QVERIFY(comp1all.contains(QStringLiteral("file.")));
-    QVERIFY(comp1all.contains(QStringLiteral("file_subdir/")));
+    QVERIFY(comp1all.contains(QLatin1String("file1")));
+    QVERIFY(comp1all.contains(QLatin1String("file#a")));
+    QVERIFY(comp1all.contains(QLatin1String("file.")));
+    QVERIFY(comp1all.contains(QLatin1String("file_subdir/")));
     QString comp1 = m_completion->replacedPath(QStringLiteral("file1")); // like KUrlRequester does
     QCOMPARE(comp1, QStringLiteral("file1"));
 
     // Completion from relative path
-    qDebug() << endl << "now completing on 'file#'";
+    qDebug() << "\nnow completing on 'file#'";
     m_completion->makeCompletion(QStringLiteral("file#"));
     QVERIFY(!m_completion->isRunning()); // last listing reused
     QStringList compall = m_completion->allMatches();
@@ -165,7 +165,7 @@ void KUrlCompletionTest::testLocalRelativePath()
     QCOMPARE(comp2, QStringLiteral("file#a"));
 
     // Completion with empty string
-    qDebug() << endl << "now completing on ''";
+    qDebug() << "\nnow completing on ''";
     m_completion->makeCompletion(QLatin1String(""));
     waitForCompletion(m_completion);
     QStringList compEmpty = m_completion->allMatches();
@@ -175,36 +175,36 @@ void KUrlCompletionTest::testLocalRelativePath()
     waitForCompletion(m_completion);
     const auto compAllHidden = m_completion->allMatches();
     QCOMPARE(compAllHidden.count(), 2);
-    QVERIFY(compAllHidden.contains(QStringLiteral(".1_hidden_file_subdir/")));
-    QVERIFY(compAllHidden.contains(QStringLiteral(".2_hidden_file_subdir/")));
+    QVERIFY(compAllHidden.contains(QLatin1String(".1_hidden_file_subdir/")));
+    QVERIFY(compAllHidden.contains(QLatin1String(".2_hidden_file_subdir/")));
 
     // Completion with '.2', should find only hidden folders starting with '2'
     m_completion->makeCompletion(QStringLiteral(".2"));
     waitForCompletion(m_completion);
     const auto compHiddenStartingWith2 = m_completion->allMatches();
     QCOMPARE(compHiddenStartingWith2.count(), 1);
-    QVERIFY(compHiddenStartingWith2.contains(QStringLiteral(".2_hidden_file_subdir/")));
+    QVERIFY(compHiddenStartingWith2.contains(QLatin1String(".2_hidden_file_subdir/")));
 
     // Completion with 'file.', should only find one file
     m_completion->makeCompletion(QStringLiteral("file."));
     waitForCompletion(m_completion);
     const auto compFileEndingWithDot = m_completion->allMatches();
     QCOMPARE(compFileEndingWithDot.count(), 1);
-    QVERIFY(compFileEndingWithDot.contains(QStringLiteral("file.")));
+    QVERIFY(compFileEndingWithDot.contains(QLatin1String("file.")));
 
     // Completion with 'source' should only find the C++ file
     m_completionWithMimeFilter->makeCompletion(QStringLiteral("source"));
     waitForCompletion(m_completionWithMimeFilter);
     const auto compSourceFile = m_completionWithMimeFilter->allMatches();
     QCOMPARE(compSourceFile.count(), 1);
-    QVERIFY(compSourceFile.contains(QStringLiteral("source.cpp")));
+    QVERIFY(compSourceFile.contains(QLatin1String("source.cpp")));
 
     // But it should also be able to find folders
     m_completionWithMimeFilter->makeCompletion(QStringLiteral("file_subdir"));
     waitForCompletion(m_completionWithMimeFilter);
     const auto compMimeFolder = m_completionWithMimeFilter->allMatches();
     QCOMPARE(compMimeFolder.count(), 1);
-    QVERIFY(compMimeFolder.contains(QStringLiteral("file_subdir/")));
+    QVERIFY(compMimeFolder.contains(QLatin1String("file_subdir/")));
 }
 
 void KUrlCompletionTest::testLocalAbsolutePath()
@@ -222,7 +222,7 @@ void KUrlCompletionTest::testLocalAbsolutePath()
     QCOMPARE(comp, QString(m_dir + "file#a"));
 
     // Completion with '.', should find all hidden folders
-    m_completion->makeCompletion(m_dir + ".");
+    m_completion->makeCompletion(m_dir + QLatin1Char('.'));
     waitForCompletion(m_completion);
     const auto compAllHidden = m_completion->allMatches();
     QCOMPARE(compAllHidden.count(), 2);
@@ -297,8 +297,8 @@ void KUrlCompletionTest::testLocalURL()
     QVERIFY(m_completion->allMatches().isEmpty());
 
     // Completion with '.', should find all hidden folders
-    qDebug() << "makeCompletion(" << (m_dirURL.toString() + ".") << ")";
-    m_completion->makeCompletion(m_dirURL.toString() + ".");
+    qDebug() << "makeCompletion(" << (m_dirURL.toString() + QLatin1Char('.')) << ")";
+    m_completion->makeCompletion(m_dirURL.toString() + QLatin1Char('.'));
     waitForCompletion(m_completion);
     const auto compAllHidden = m_completion->allMatches();
     QCOMPARE(compAllHidden.count(), 2);
@@ -341,7 +341,7 @@ void KUrlCompletionTest::testLocalURL()
 void KUrlCompletionTest::testEmptyCwd()
 {
     // Completion with empty string (with a KUrlCompletion whose cwd is "")
-    qDebug() << endl << "now completing on '' with empty cwd";
+    qDebug() << "\nnow completing on '' with empty cwd";
     m_completionEmptyCwd->makeCompletion(QLatin1String(""));
     waitForCompletion(m_completionEmptyCwd);
     QStringList compEmpty = m_completionEmptyCwd->allMatches();
@@ -369,10 +369,11 @@ void KUrlCompletionTest::testUser()
     m_completionEmptyCwd->makeCompletion(QStringLiteral("~"));
     waitForCompletion(m_completionEmptyCwd);
     const auto matches = m_completionEmptyCwd->allMatches();
-    if (!KUser::allUserNames().isEmpty()) {
+    const QStringList allUsers = KUser::allUserNames();
+    if (!allUsers.isEmpty()) {
         Q_ASSERT(!matches.isEmpty());
     }
-    foreach (const auto &user, KUser::allUserNames()) {
+    for (const auto &user : allUsers) {
         QVERIFY2(matches.contains(QLatin1Char('~') + user), qPrintable(matches.join(QLatin1Char(' '))));
     }
 
@@ -415,7 +416,8 @@ void KUrlCompletionTest::testCancel()
         QVERIFY2(!match.startsWith(QLatin1Char('g')), qPrintable(match));
     }
     waitForCompletion(&comp);
-    foreach (const QString &match, comp.allMatches()) {
+    const QStringList matchesB = comp.allMatches();
+    for (const QString &match : matchesB) {
         QVERIFY2(!match.startsWith(QLatin1Char('g')), qPrintable(match));
     }
 }
