@@ -21,6 +21,7 @@
 
 #include "deletejob.h"
 
+#include "global.h"
 #include "job.h" // buildErrorString
 #include "statjob.h"
 #include "listjob.h"
@@ -314,7 +315,7 @@ void DeleteJobPrivate::statNextSrc()
             // Done, jump to the last else of this method
             statNextSrc();
         } else {
-            KIO::SimpleJob *job = KIO::stat(m_currentURL, StatJob::SourceSide, 0, KIO::HideProgressInfo);
+            KIO::SimpleJob *job = KIO::statDetails(m_currentURL, StatJob::SourceSide, KIO::StatBasic, KIO::HideProgressInfo);
             Scheduler::setJobPriority(job, 1);
             //qDebug() << "stat'ing" << m_currentURL;
             q->addSubjob(job);
@@ -501,7 +502,11 @@ void DeleteJobPrivate::currentSourceStated(bool isDir, bool isLink)
         if (!KProtocolManager::canDeleteRecursive(url)) {
             //qDebug() << url << "is a directory, let's list it";
             ListJob *newjob = KIO::listRecursive(url, KIO::HideProgressInfo);
+#if KIOCORE_BUILD_DEPRECATED_SINCE(5, 69)
+            // TODO KF6: remove legacy details code path
             newjob->addMetaData(QStringLiteral("details"), QStringLiteral("0"));
+#endif
+            newjob->addMetaData(QStringLiteral("statDetails"), QString::number(KIO::StatBasic));
             newjob->setUnrestricted(true); // No KIOSK restrictions
             Scheduler::setJobPriority(newjob, 1);
             QObject::connect(newjob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
