@@ -58,6 +58,7 @@
 #include <kio/jobuidelegate.h>
 #include <kio/previewjob.h>
 #include <KIO/OpenFileManagerWindowJob>
+#include <KIO/RenameFileDialog>
 #include <kfilepreviewgenerator.h>
 #include <krun.h>
 #include <kpropertiesdialog.h>
@@ -427,6 +428,7 @@ void KDirOperator::updateSelectionDependentActions()
 {
     const bool hasSelection = (d->itemView != nullptr) &&
                               d->itemView->selectionModel()->hasSelection();
+    d->actionCollection->action(QStringLiteral("rename"))->setEnabled(hasSelection);
     d->actionCollection->action(QStringLiteral("trash"))->setEnabled(hasSelection);
     d->actionCollection->action(QStringLiteral("delete"))->setEnabled(hasSelection);
     d->actionCollection->action(QStringLiteral("properties"))->setEnabled(hasSelection);
@@ -726,7 +728,11 @@ bool KDirOperator::mkdir(const QString &directory, bool enterDirectory)
     bool exists = false;
     QUrl folderurl(d->currUrl);
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList dirs = directory.split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+    const QStringList dirs = directory.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
     QStringList::ConstIterator it = dirs.begin();
 
     for (; it != dirs.end(); ++it) {
@@ -736,7 +742,7 @@ bool KDirOperator::mkdir(const QString &directory, bool enterDirectory)
         } else {
             KIO::StatJob *job = KIO::stat(folderurl);
             KJobWidgets::setWindow(job, this);
-            job->setDetails(0); //We only want to know if it exists, 0 == that.
+            job->setDetails(KIO::StatNoDetails); //We only want to know if it exists
             job->setSide(KIO::StatJob::DestinationSide);
             exists = job->exec();
         }
@@ -865,6 +871,23 @@ bool KDirOperator::isSaving() const
     return d->isSaving;
 }
 
+void KDirOperator::renameSelected()
+{
+    if (d->itemView == nullptr) {
+        return;
+    }
+
+    const KFileItemList items = selectedItems();
+    if (items.isEmpty()) {
+        return;
+    }
+
+    KIO::RenameFileDialog* dialog = new KIO::RenameFileDialog(items, this);
+    connect(dialog, SIGNAL(renamingFinished()), SLOT(_k_assureVisibleSelection()));
+
+    dialog->open();
+}
+
 void KDirOperator::trashSelected()
 {
     if (d->itemView == nullptr) {
@@ -1465,7 +1488,11 @@ bool KDirOperator::Private::checkPreviewInternal() const
     }
 
     const QStringList mimeTypes = dirLister->mimeFilters();
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList nameFilters = dirLister->nameFilter().split(QLatin1Char(' '), QString::SkipEmptyParts);
+#else
+    const QStringList nameFilters = dirLister->nameFilter().split(QLatin1Char(' '), Qt::SkipEmptyParts);
+#endif
 
     if (mimeTypes.isEmpty() && nameFilters.isEmpty() && !supported.isEmpty()) {
         return true;
@@ -1949,6 +1976,9 @@ void KDirOperator::setupActions()
     mkdirAction->setIcon(QIcon::fromTheme(QStringLiteral("folder-new")));
     connect(mkdirAction, SIGNAL(triggered(bool)), this, SLOT(mkdir()));
 
+    QAction *rename = KStandardAction::renameFile(this, &KDirOperator::renameSelected, this);
+    d->actionCollection->addAction(QStringLiteral("rename"), rename);
+
     QAction *trash = new QAction(i18n("Move to Trash"), this);
     d->actionCollection->addAction(QStringLiteral("trash"), trash);
     trash->setIcon(QIcon::fromTheme(QStringLiteral("user-trash")));
@@ -2083,7 +2113,7 @@ void KDirOperator::setupActions()
 
     KToggleAction *showHiddenAction = new KToggleAction(i18n("Show Hidden Files"), this);
     d->actionCollection->addAction(QStringLiteral("show hidden"), showHiddenAction);
-    showHiddenAction->setShortcuts({Qt::ALT + Qt::Key_Period, Qt::CTRL + Qt::Key_H, Qt::Key_F8});
+    showHiddenAction->setShortcuts(KStandardShortcut::showHideHiddenFiles());
     connect(showHiddenAction, SIGNAL(toggled(bool)), SLOT(_k_slotToggleHidden(bool)));
 
     KToggleAction *previewAction = new KToggleAction(i18n("Show Preview Panel"), this);
@@ -2162,6 +2192,10 @@ void KDirOperator::setupMenu(int whichActions)
 
     if (whichActions & FileActions) {
         d->actionMenu->addAction(d->actionCollection->action(QStringLiteral("new")));
+
+        d->actionMenu->addAction(d->actionCollection->action(QStringLiteral("rename")));
+        d->actionCollection->action(QStringLiteral("rename"))->setEnabled(KProtocolManager::supportsMoving(d->currUrl));
+
         if (d->currUrl.isLocalFile() && !(QApplication::keyboardModifiers() & Qt::ShiftModifier)) {
             d->actionMenu->addAction(d->actionCollection->action(QStringLiteral("trash")));
         }
